OC.L10N.register(
    "files_trashbin",
    {
    "Deleted files" : "فایل های حذف شده",
    "restored" : "بازیابی شد",
    "Restore" : "بازیابی",
    "Delete permanently" : "حذف قطعی",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "No deleted files" : "هیچ فایل حذف شده وجود ندارد",
    "You will be able to recover deleted files from here" : "شما قادر خواهید بود فایل های حذف شده را از اینجا بازیابی کنید",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Name" : "نام",
    "Actions" : "فعالیت ها",
    "Deleted" : "حذف شده",
    "Delete" : "حذف"
},
"nplurals=2; plural=(n > 1);");
